## How to contribute

Thank you for considering contributing to htmldate!

Here are some important resources:

  * [List of currently open issues](https://github.com/adbar/htmldate/issues) (no pretention to exhaustivity!)
  * [How to Contribute to Open Source](https://opensource.guide/how-to-contribute/)

There are many ways to contribute, you could:

  * Improve the documentation
  * Find bugs and submit bug reports
  * Submit feature requests
  * Write tutorials or blog posts
  * Write code

## Submitting changes

Please send a [GitHub Pull Request to htmldate](https://github.com/adbar/htmldate/pull/new/master) with a clear list of what you've done (read more about [pull requests](http://help.github.com/pull-requests/)).

**Working on your first Pull Request?** You can learn how from this series: [How to Contribute to an Open Source Project on GitHub](https://egghead.io/series/how-to-contribute-to-an-open-source-project-on-github)

For further questions you can contact me on [GitHub issues](), [Twitter](https://twitter.com/adbarbaresi) or by [E-Mail](http://adrien.barbaresi.eu/contact.html)


Thanks,

Adrien